lda\_over\_time.models package
==============================

Submodules
----------

lda\_over\_time.models.dtm\_model\_interface module
---------------------------------------------------

.. automodule:: lda_over_time.models.dtm_model_interface
   :members:
   :undoc-members:
   :show-inheritance:

lda\_over\_time.models.lda\_seq\_model module
---------------------------------------------

.. automodule:: lda_over_time.models.lda_seq_model
   :members:
   :undoc-members:
   :show-inheritance:

lda\_over\_time.models.prevalence\_model module
-----------------------------------------------

.. automodule:: lda_over_time.models.prevalence_model
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: lda_over_time.models
   :members:
   :undoc-members:
   :show-inheritance:
